<?php
/*
The purpose of the Script is to check whether web site supports perfect forward secrecy. 
Input: URL of the website
Output: List of cipher and result whether website supports PFS.
*/

//URL of the website
$url = "https://www.yioop.com/";

echo '<span style="font-family:Tahoma;color:red;font-size:150%">Testing SSL server:'.$url. '</span>';
echo nl2br("\n\n");

//List of ciphers, which allow forward secrecy.There may be more than these ciphers which allows forward secrecy.
$forwardsSerecyCiphers = array("DHE-RSA-AES256-SHA","DHE-RSA-AES128-SHA","EDH-RSA-DES-CBC3-SHA","ECDHE-RSA-AES256-SHA");

//Ciphers against which test is performed
$ciphers = array("ADH-AES256-SHA","DHE-RSA-AES256-SHA","DHE-DSS-AES256-SHA","AES256-SHA","ADH-AES128-SHA",
                 "DHE-RSA-AES128-SHA","DHE-DSS-AES128-SHA","ECDHE-RSA-AES256-SHA","AES128-SHA","ADH-DES-CBC3-SHA",
				 "ADH-DES-CBC-SHA","EXP-ADH-DES-CBC-SHA","ADH-RC4-MD5","EXP-ADH-RC4-MD5","EDH-RSA-DES-CBC3-SHA",
				 "EDH-RSA-DES-CBC-SHA","EXP-EDH-RSA-DES-CBC-SHA","EDH-DSS-DES-CBC3-SHA","EDH-DSS-DES-CBC-SHA",
				 "EXP-EDH-DSS-DES-CBC-SHA","DES-CBC3-SHA","DES-CBC-SHA","EXP-DES-CBC-SHA","IDEA-CBC-SHA",
				 "EXP-RC2-CBC-MD5","RC4-SHA","RC4-MD5","EXP-RC4-MD5","DES-CBC3-MD5","DES-CBC-MD5","IDEA-CBC-MD5",
				 "EXP-RC2-CBC-MD5","RC2-CBC-MD5","EXP-RC4-MD5","RC4-MD5");

$ch = curl_init($url);
curl_setopt($ch,CURLOPT_RETURNTRANSFER, 1); 
curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 200);
curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
curl_setopt($ch, CURLOPT_SSL_VERIFYHOST,2);
curl_setopt($ch, CURLOPT_HEADER, true);
curl_setopt($ch, CURLOPT_VERBOSE, true);
curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 GTB5');
curl_setopt($ch, CURLOPT_FOLLOWLOCATION,true);

$max = sizeof($ciphers );

//constant used to keep track whether website supports PFS
$pfsSupport = "No";

for ($x=0; $x<$max; $x++)
{
    //Selecting one cipher from cipher array and make curl request
	curl_setopt($ch, CURLOPT_SSL_CIPHER_LIST,$ciphers[$x]);
	$curl_scraped_page= curl_exec($ch);
	$httpCode=curl_getinfo($ch, CURLINFO_HTTP_CODE); 
	
	//Verifying response. Cipher is not supported by website if response httpcode is zero and if we have't received anything in response
	if(!$curl_scraped_page && $httpCode==0)
	{
	    //To check given cipher is part of cipher family which provide perfect secrecy.
		if (in_array($ciphers[$x], $forwardsSerecyCiphers)) 
		{
			echo '<span style="color:red;"/>';
		}
		echo nl2br("Cipher: ".$ciphers[$x]." - Not Supported"."\n");
		echo '<span style="color:black;"/>';
	}
	//Cipher is supported by website if response httpcode is 200 and if we have received response page from website.
	if($curl_scraped_page && $httpCode==200)
	{
		if (in_array($ciphers[$x], $forwardsSerecyCiphers)) {
		echo '<span style="color:blue;"/>';
		$pfsSupport = "Yes";
	}
		echo nl2br("Cipher: ".$ciphers[$x]." - Supported"."\n");
		echo '<span style="color:black;"/>';
	}
}

echo nl2br("\n");
echo '<span style="font-family:Tahoma;color:red;font-size:150%">PFS Support:'.$pfsSupport. '</span>';
echo nl2br("\n");

//Printing request header
echo nl2br("\n");
echo '<span style="font-family:Tahoma;color:red;font-size:150%">Request Header</span>';
echo nl2br("\n");
var_dump(curl_getinfo($ch));

//Printing response header
echo nl2br("\n\n");
echo '<span style="font-family:Tahoma;color:red;font-size:150%">Response Header</span>';
echo nl2br("\n");
print_r(get_headers($url));
curl_close($ch);
?>
